@@ -43,20 +43,6 @@ class TestUsers(TestOrganizationMixin, TestCase):
         u.save()
         self.assertIsNone(u.email)
 
-    def test_organizations_pk(self):
-        user = self._create_user(username='organizations_pk')
-        org1 = self._create_org(name='org1')
-        org2 = self._create_org(name='org2')
-        self._create_org(name='org3')
-        OrganizationUser.objects.create(user=user, organization=org1)
-        OrganizationUser.objects.create(user=user, organization=org2)
-        self.assertIn((org1.pk,), user.organizations_pk)
-        self.assertEqual(len(user.organizations_pk), 2)
-
-    def test_organizations_pk_empty(self):
-        user = self._create_user(username='organizations_pk')
-        self.assertEqual(len(user.organizations_pk), 0)
-
     def test_organizations_dict(self):
         user = self._create_user(username='organizations_pk')
         self.assertEqual(user.organizations_dict, {})
